@@ -24,8 +24,10 @@
 #include <dune/istl/solvers.hh>
 #include <cstdlib>
 #include <ctime>
+#include <complex>
 
 typedef double XREAL;
+// typedef std::complex<double> XREAL;
 
 /*
    typedef HPA::xreal XREAL;
@@ -99,8 +101,10 @@ void testAMG(int N, int coarsenTarget, int ml)
   watch.reset();
   Operator fop(mat);
 
-  typedef Dune::Amg::CoarsenCriterion<Dune::Amg::UnSymmetricCriterion<BCRSMat,Dune::Amg::FirstDiagonal> >
-  Criterion;
+  typedef typename std::conditional< std::is_convertible<XREAL, typename Dune::FieldTraits<XREAL>::real_type>::value,
+                   Dune::Amg::FirstDiagonal, Dune::Amg::RowSum >::type Norm;
+  typedef Dune::Amg::CoarsenCriterion<Dune::Amg::UnSymmetricCriterion<BCRSMat,Norm> >
+          Criterion;
   typedef Dune::SeqSSOR<BCRSMat,Vector,Vector> Smoother;
   //typedef Dune::SeqSOR<BCRSMat,Vector,Vector> Smoother;
   //typedef Dune::SeqJac<BCRSMat,Vector,Vector> Smoother;
@@ -161,8 +165,8 @@ void testAMG(int N, int coarsenTarget, int ml)
 
 
 int main(int argc, char** argv)
+try
 {
-
   int N=100;
   int coarsenTarget=1200;
   int ml=10;
@@ -179,4 +183,14 @@ int main(int argc, char** argv)
   testAMG<1>(N, coarsenTarget, ml);
   testAMG<2>(N, coarsenTarget, ml);
 
+  return 0;
+}
+catch (std::exception &e)
+{
+  throw;
+}
+catch (...)
+{
+  std::cerr << "Dune reported an unknown error." << std::endl;
+  exit(1);
 }
