@@ -49,24 +49,11 @@ struct Builder<Dune::BCRSMatrix<B,A> >
     /*{
 
        Dune::BCRSMatrix<B,A> matrix( rows, cols, rows*maxNZCols, Dune::BCRSMatrix<B,A>::random );
-       for(int i=0; i<rows; ++i){
-        matrix.setrowsize(i,maxNZCols);
-        if(i<cols)
-          matrix.addindex(i,i);
-        if(i-1>=0)
-          matrix.addindex(i,i-1);
-        if(i+1<cols)
-          matrix.addindex(i,i+1);
-       }
+       for(int i=0; i<rows; ++i)
+         matrix.setrowsize(i,maxNZCols);
        matrix.endrowsizes();
 
-       Dune::printmatrix(std::cout, matrix, "random", "row");
-       }
-       {
-
-       Dune::BCRSMatrix<B,A> matrix( rows, cols, Dune::BCRSMatrix<B,A>::random );
        for(int i=0; i<rows; ++i){
-        matrix.setrowsize(i,maxNZCols);
         if(i<cols)
           matrix.addindex(i,i);
         if(i-1>=0)
